@@ -4,7 +4,7 @@ Created on Fri Jun 18 09:43:48 2021
 
 @author: dcr
 """
-from .logic import Logic
+from .logic.bitwise import *
 from .base import Wire
 import math
 
@@ -252,7 +252,33 @@ class BitSymbol(LogicSymbol):
     def getWireSinkPos(self, wire:Wire):
         return (0, namemargin + 10)
     
-class OrSymbol(LogicSymbol):
+class RangeSymbol(LogicSymbol):
+    def __init__(self, obj, x, y):
+        super().__init__(obj, x, y)
+
+    def draw(self, canvas):
+        x = self.x
+        y = self.y
+
+        canvas.drawText(x, y, text='[{}:{}]'.format(self.obj.high, self.obj.low), anchor='w')
+        y = y + namemargin 
+
+        canvas.drawLine(x+10,y, x, y+20)
+        #canvas.drawPolygon([x, x + 20, x, x], [y, y + 10, y + 20, y])
+        
+    def getHeight(self):
+        return 20
+
+    def getWidth(self):
+        return 20
+
+    def getWireSourcePos(self, wire:Wire):
+        return (10, namemargin + 10)
+    
+    def getWireSinkPos(self, wire:Wire):
+        return (0, namemargin + 10)
+    
+class NorSymbol(LogicSymbol):
     def __init__(self, obj, x, y):
         super().__init__(obj, x, y)
         self.h = 40
@@ -273,6 +299,62 @@ class OrSymbol(LogicSymbol):
         canvas.drawArc(x-30 , y, x + 50+20, y + self.h*4, start=-90, extent=-60) #, style=tkinter.ARC, outline='black', fill='white')
         canvas.drawArc(x-30 , y-self.h*3, x + 50+20, y + self.h, start=60, extent=90) #, style=tkinter.ARC, outline='black', fill='white')
 
+        canvas.drawEllipse(x + 55, y + 15, x + 65, y + 25)
+
+    def getHeight(self):
+        return namemargin + self.h
+
+    def getWidth(self):
+        return 65
+    
+    def getWireSourcePos(self, wire:Wire):
+        return (self.getWidth(), namemargin + self.h//2)
+    
+    def getWireSinkPos(self, wire:Wire):
+        selidx = -1
+        for idx, port in enumerate(self.obj.inPorts):
+            if (port.wire == wire):
+                selidx = idx
+                
+        if (selidx == -1):
+            raise Exception('in port not found in {}'.format(self.obj.getFullPath()) )
+
+        if (selidx == 0):
+            y = self.h//2 - 10
+        else:
+            y = self.h//2 + 10 
+
+        return (5, namemargin + y)
+    
+class OrSymbol(LogicSymbol):
+    def __init__(self, obj, x, y):
+        super().__init__(obj, x, y)
+        
+        if (isinstance(obj, Or2)):
+            self.nins = 2
+        else:
+            self.nins = len(obj.ins)
+
+        self.h = 20 * self.nins
+        
+    def draw(self, canvas):
+        x = self.x
+        y = self.y
+
+        canvas.drawText(x, y, text=self.obj.name, anchor='w')
+        y = y + namemargin
+
+        # the and box would be x[0:50] y[0:30]
+        canvas.drawLine(x, y, x + 20, y)
+        canvas.drawLine(x, y + self.h, x + 20, y + self.h)
+        canvas.drawArc(x-10 , y, x + 10, y + self.h, start=-90, extent=90) #, style=tkinter.ARC, outline='black', fill='white')
+
+        #canvas.drawLine(x, y, x, y + self.h)
+        #canvas.drawArc(x-30 , y, x + 50+20, y + self.h + (self.nins+1)*40, start=-90, extent=-60) #, style=tkinter.ARC, outline='black', fill='white')
+        #canvas.drawArc(x-30 , y - (self.nins+1)*40, x + 50+20, y + self.h, start=60, extent=90) #, style=tkinter.ARC, outline='black', fill='white')
+        canvas.drawSpline([x+20, x+30, x+42, x+50], [y,  y+2, y+self.h//4, y+self.h//2])
+        canvas.drawSpline([x+20, x+30, x+42, x+50], [y+self.h,  y+self.h-2, y+self.h-self.h//4, y+self.h//2])
+
     def getHeight(self):
         return namemargin + self.h
 
@@ -282,6 +364,51 @@ class OrSymbol(LogicSymbol):
     def getWireSourcePos(self, wire:Wire):
         return (self.getWidth(), namemargin + self.h//2)
     
+    def getWireSinkPos(self, wire:Wire):
+        selidx = -1
+        for idx, port in enumerate(self.obj.inPorts):
+            if (port.wire == wire):
+                selidx = idx
+                
+        if (selidx == -1):
+            raise Exception('in port not found in {}'.format(self.obj.getFullPath()) )
+
+        y = 10 + selidx * 20
+
+        return (5, namemargin + y)
+    
+class XorSymbol(LogicSymbol):
+    def __init__(self, obj, x, y):
+        super().__init__(obj, x, y)
+        self.h = 40
+
+    def draw(self, canvas):
+        x = self.x
+        y = self.y
+
+        canvas.drawText(x, y, text=self.obj.name, anchor='w')
+        y = y + namemargin
+
+        # the and box would be x[0:50] y[0:30]
+        canvas.drawLine(x+10, y, x + 20+10, y)
+        canvas.drawLine(x+10, y + self.h, x + 20+10, y + self.h)
+        canvas.drawArc(x-10 , y, x + 10, y + self.h, start=-90, extent=90) #, style=tkinter.ARC, outline='black', fill='white')
+        canvas.drawArc(x , y, x + 20, y + self.h, start=-90, extent=90) #, style=tkinter.ARC, outline='black', fill='white')
+
+        canvas.drawArc(x-30 +10, y, x + 50+20+10, y + self.h*4, start=-90, extent=-60) #, style=tkinter.ARC, outline='black', fill='white')
+        canvas.drawArc(x-30 +10, y-self.h*3, x + 50+20+10, y + self.h, start=60, extent=90) #, style=tkinter.ARC, outline='black', fill='white')
+
+
+
+    def getHeight(self):
+        return namemargin + self.h
+
+    def getWidth(self):
+        return 50+10
+    
+    def getWireSourcePos(self, wire:Wire):
+        return (self.getWidth(), namemargin + self.h//2)
+    
     def getWireSinkPos(self, wire:Wire):
         selidx = -1
         for idx, port in enumerate(self.obj.inPorts):
@@ -524,7 +651,17 @@ class FeedbackStartSymbol(LogicSymbol):
         return 30
     
     def draw(self, canvas):
-        pass
+        x = self.x
+        y = self.y
+        
+        canvas.setForecolor('red')  
+        canvas.setLineWidth(1)
+        
+        #canvas.drawRectangle(x, y, x+30, y+30)
+        canvas.drawLine(x, y+15, x+30, y+15)
+
+        canvas.setForecolor('k')  
+        canvas.setLineWidth(2)
         
     def getWireSinkPos(self, wire:Wire):
         return (0, 15);
@@ -543,7 +680,17 @@ class FeedbackStopSymbol(LogicSymbol):
         return 30
     
     def draw(self, canvas):
-        pass
+        x = self.x
+        y = self.y
+        
+        canvas.setForecolor('red')  
+        canvas.setLineWidth(1)
+        
+        #canvas.drawRectangle(x, y, x+30, y+30)
+        canvas.drawLine(x, y+15, x+30, y+15)
+
+        canvas.setForecolor('k')  
+        canvas.setLineWidth(2)
         
     def getWireSinkPos(self, wire:Wire):
         return (0, 15);
@@ -553,7 +700,25 @@ class FeedbackStopSymbol(LogicSymbol):
     
     
 class NetSymbol:
-    def __init__(self, source, sink):
+    def __init__(self, wire:Wire, source:LogicSymbol, sink:LogicSymbol):
+        """
+        Constructor of net symbol
+
+        Parameters
+        ----------
+        wire : Wire
+            Associated wire.
+        source : LogicSymbol
+            source logic symbol.
+        sink : LogicSymbol
+            sink logic symbol.
+
+        Returns
+        -------
+        None.
+
+        """
+        self.wire = wire
         self.source = source
         self.sink = sink
         self.x = None
@@ -562,13 +727,13 @@ class NetSymbol:
         self.arrow = True
         
     def getStartPoint(self):
-        objsource = self.source['symbol']
-        portsource = objsource.getWireSourcePos(self.source['wire'])
+        objsource = self.source
+        portsource = objsource.getWireSourcePos(self.wire)
         return (objsource.x + portsource[0], objsource.y + portsource[1]) 
     
     def getEndPoint(self):
-        objsink = self.sink['symbol']
-        portsink = objsink.getWireSinkPos(self.source['wire'])
+        objsink = self.sink
+        portsink = objsink.getWireSinkPos(self.wire)
         return (objsink.x + portsink[0], objsink.y + portsink[1]) 
     
     def setPath(self, x, y):
